API Documentation
=================

.. include:: api-note.rst

.. toctree::
   :maxdepth: 2

   documents
   nodes
   querying
   serialization
   transformations
   utilities
   typing
   exceptions
   extending
